"use strict";

var ACTION_TYPES = {
  FETCH_PAGE_DATA: 'FETCH_PAGE_DATA',
  UPDATE_PAGE_DATA: 'UPDATE_PAGE_DATA',
  ERROR_OCCURED: 'ERROR_OCCURED',
  OFFLINE_MODE: 'OFFLINE_MODE'
};

var updatePageData = function updatePageData() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      match = _ref.match,
      route = _ref.route,
      data = _ref.data;

  return {
    type: ACTION_TYPES.UPDATE_PAGE_DATA,
    match: match,
    route: route,
    data: data
  };
};

var handleError = function handleError(error) {
  return {
    type: ACTION_TYPES.ERROR_OCCURED,
    error: error
  };
};

var handleOffline = function handleOffline() {
  return {
    type: ACTION_TYPES.OFFLINE_MODE
  };
};

var fetchPageData = function fetchPageData() {
  var _ref2 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      route = _ref2.route,
      match = _ref2.match;

  return function (dispatch, getState) {
    dispatch({
      type: ACTION_TYPES.FETCH_PAGE_DATA,
      route: route,
      match: match
    });
    return route.fetcher({
      route: route,
      match: match
    }).then(function (response) {
      return dispatch(updatePageData({
        match: match,
        route: route,
        data: response.data
      }));
    });
  };
};

module.exports = {
  ACTION_TYPES: ACTION_TYPES,
  fetchPageData: fetchPageData,
  updatePageData: updatePageData,
  handleError: handleError,
  handleOffline: handleOffline
};